



import os
from os.path import join
from os import makedirs
from pathlib import Path
import logging

LOG = logging.getLogger(__name__)


try:
    makedirs(join(Path.home(), '.pygadget'))
except OSError:
    LOG.info('.pygadget already exists. skipping.')
except Exception as e:
    raise RuntimeError(f'unhandled exceptions {str(e)}')
else:
    LOG.info('.pygadget dir created')




    






import pygadget.comp.boyorgirl as t1

def test_1(capsys):
    input_values = ['xiaodao']

    def mock_input():
        return input_values.pop(0)
    t1.input = mock_input

    t1.main()

    out, err = capsys.readouterr()

    assert out == 'IGNORE HIM!\n'
    assert err == ''





